@@ -17,6 +17,13 @@ from gaiatest import GaiaData
 from gaiatest import GaiaDevice
 
 
+class CountError(Exception):
+    """Exception for a count being incorrect"""
+    def __init__(self, type, expected, actual):
+        Exception.__init__(
+            self, 'Incorrect number of %s. Expected %s but found %s' % (type, expected, actual))
+
+
 class B2GPopulate:
 
     def __init__(self, marionette):
@@ -27,9 +34,18 @@ class B2GPopulate:
     def populate(self, contact_count=0, message_count=0, music_count=0,
                  picture_count=0, video_count=0):
 
-        if self.device.is_android_build and self.data_layer.media_files:
-            for filename in self.data_layer.media_files:
-                self.device.manager.removeFile('/'.join(['sdcard', filename]))
+        if self.device.is_android_build:
+            media_files = self.data_layer.media_files or []
+            if len(media_files) > 0:
+                progress = ProgressBar(widgets=[
+                    'Removing Media: ',
+                    '[', Counter(),
+                    '/%d] ' % len(media_files)], maxval=len(media_files))
+                for filename in progress(media_files):
+                    self.device.manager.removeFile(filename)
+                media_files = self.data_layer.media_files
+            if not len(media_files) == 0:
+                raise CountError('media files', 0, len(media_files))
 
         if contact_count:
             self.populate_contacts(contact_count)
@@ -47,14 +63,17 @@ class B2GPopulate:
             self.populate_files('videos', 'VID_0001.3gp', video_count, 'sdcard/DCIM/100MZLLA')
 
     def populate_contacts(self, count):
-        progress = ProgressBar(widgets=['Contacts: ', '[', Counter(), '/%d] ' % count], maxval=count)
+        progress = ProgressBar(widgets=[
+            'Contacts: ', '[', Counter(), '/%d] ' % count], maxval=count)
         progress.start()
         for marker in [2000, 1000, 500, 200, 0]:
             if count >= marker:
-                db_zip = ZipFile(pkg_resources.resource_filename(__name__, os.path.sep.join(['resources', 'contactsDb.zip'])))
+                db_zip = ZipFile(pkg_resources.resource_filename(
+                    __name__, os.path.sep.join(['resources', 'contactsDb.zip'])))
                 db = db_zip.extract('contactsDb-%d.sqlite' % marker)
                 self.device.stop_b2g()
-                self.device.push_file(db, destination='data/local/indexedDB/chrome/3406066227csotncta.sqlite')
+                self.device.push_file(
+                    db, destination='data/local/indexedDB/chrome/3406066227csotncta.sqlite')
                 os.remove(db)
                 self.device.start_b2g()
                 progress.update(marker)
@@ -71,16 +90,20 @@ class B2GPopulate:
         # only allow preset db values for messages
         db_message_counts = [0, 200, 500, 1000, 2000]
         if not count in db_message_counts:
-            raise Exception('Invalid value for message count, use one of: %s' % ', '.join([str(count) for count in db_message_counts]))
-        progress = ProgressBar(widgets=['Messages: ', '[', Counter(), '/%d] ' % count], maxval=count)
+            raise Exception('Invalid value for message count, use one of: %s' %
+                            ', '.join([str(count) for count in db_message_counts]))
+        progress = ProgressBar(widgets=[
+            'Messages: ', '[', Counter(), '/%d] ' % count], maxval=count)
         progress.start()
         db_message_counts.sort(reverse=True)
         for marker in db_message_counts:
             if count >= marker:
-                db_zip = ZipFile(pkg_resources.resource_filename(__name__, os.path.sep.join(['resources', 'smsDb.zip'])))
+                db_zip = ZipFile(pkg_resources.resource_filename(
+                    __name__, os.path.sep.join(['resources', 'smsDb.zip'])))
                 db = db_zip.extract('smsDb-%d.sqlite' % marker)
                 self.device.stop_b2g()
-                self.device.push_file(db, destination='data/local/indexedDB/chrome/226660312ssm.sqlite')
+                self.device.push_file(
+                    db, destination='data/local/indexedDB/chrome/226660312ssm.sqlite')
                 os.remove(db)
                 self.device.start_b2g()
                 progress.update(marker)
@@ -90,7 +113,8 @@ class B2GPopulate:
     def populate_music(self, count, source='MUS_0001.mp3', destination='sdcard'):
         import math
         from mutagen.easyid3 import EasyID3
-        music_file = pkg_resources.resource_filename(__name__, os.path.sep.join(['resources', source]))
+        music_file = pkg_resources.resource_filename(
+            __name__, os.path.sep.join(['resources', source]))
         local_filename = music_file.rpartition(os.path.sep)[-1]
         mp3 = EasyID3(music_file)
 
@@ -185,10 +209,12 @@ def cli():
     db_message_counts = [0, 200, 500, 1000, 2000]
     if options.message_count and not options.message_count in db_message_counts:
         parser.print_usage()
-        print 'invalid value for message count, use one of: %s' % ', '.join([str(count) for count in db_message_counts])
+        print 'invalid value for message count, use one of: %s' % \
+              ', '.join([str(count) for count in db_message_counts])
         parser.exit()
 
-    marionette = Marionette(host='localhost', port=2828)  # TODO command line option for address
+    # TODO command line option for address
+    marionette = Marionette(host='localhost', port=2828, timeout=180000)
     marionette.start_session()
     B2GPopulate(marionette).populate(
         options.contact_count,
